@@ -11,7 +11,6 @@ from benchmark_runner.common.oc.oc_exceptions import VMNotCompletedTimeout
 from benchmark_runner.benchmark_operator.templates.generate_yaml_from_templates import TemplateOperations
 from benchmark_runner.common.elasticsearch.es_operations import ESOperations
 from benchmark_runner.common.ssh.ssh import SSH
-from benchmark_runner.benchmark_operator.benchmark_operator_exceptions import VMWorkloadNeedElasticSearch
 from benchmark_runner.main.environment_variables import environment_variables
 
 
@@ -23,12 +22,13 @@ class BenchmarkOperatorWorkloads:
         self.__ssh = SSH()
         self.__kubeadmin_password = kubeadmin_password
         self.__oc = OC(kubeadmin_password=self.__kubeadmin_password)
-        # if mount is exist - path inside Dockerfile
-        if os.path.exists('/benchmark_runner/benchmark_operator/templates/'):
-            self.__dir_path = '/benchmark_runner/benchmark_operator/templates/'
+        #  if mount is exist - path inside Dockerfile
+        if os.path.exists('/benchmark_runner/templates/'):
+            self.__dir_path = '/benchmark_runner/templates'
+            self.__current_run_path = f'{self.__dir_path}/current_run'
         else:
             self.__dir_path = os.path.dirname(os.path.realpath(__file__))
-        self.__current_run_path = f'{self.__dir_path}/templates/current_run'
+            self.__current_run_path = f'{self.__dir_path}/templates/current_run'
         self.__es_host = es_host
         self.__es_port = es_port
         if es_host and es_port:
@@ -39,15 +39,6 @@ class BenchmarkOperatorWorkloads:
         # environment variables
         self.__environment_variables_dict = environment_variables.environment_variables_dict
 
-    @typechecked()
-    def __verify_elasticsearch_exist_for_vm_workload(self, workload: str):
-        """
-        This method verify that elastic search exist for vm workloads to verify completed status
-        :return: error in case no elasticsearch
-        """
-        if 'vm' in workload and not self.__es_host:
-           raise VMWorkloadNeedElasticSearch
-
     def __remove_current_run_yamls(self, extension='.yaml'):
         """
         This method remove all current run yamls files
@@ -74,14 +65,14 @@ class BenchmarkOperatorWorkloads:
             logger.info('yaml file {} does not exist')
 
     @logger_time_stamp
-    def update_node_selector(self, base_path: str = '', yaml_path: str = '', pin_node: str = ''):
+    def update_node_selector(self, runner_path: str = environment_variables.environment_variables_dict['runner_path'], yaml_path: str = '', pin_node: str = ''):
         """
         This method update node selector in yaml
         @return:
         """
         data = []
         # Read YAML file and inject node selector in the right place
-        with open(os.path.join(base_path, yaml_path), 'r') as stream:
+        with open(os.path.join(runner_path, yaml_path), 'r') as stream:
             try:
                 documents = yaml.safe_load_all(stream)
                 for doc in documents:
@@ -97,28 +88,6 @@ class BenchmarkOperatorWorkloads:
                                'benchmark-operator/config/manager/manager.yaml'), 'w', encoding='utf8') as outfile:
             yaml.safe_dump_all(data, outfile, default_flow_style=False, allow_unicode=True)
 
-    @logger_time_stamp
-    def change_resource_limit_cpu_benchmark_operator_temp_patch(self, base_path: str = '', yaml_path: str = ''):
-        """
-        # This method is for update resources limit to 0 in manager.yaml
-        @return:
-        """
-        data = []
-        # Read YAML file and inject node selector in the right place
-        with open(os.path.join(base_path, yaml_path), 'r') as stream:
-            try:
-                documents = yaml.safe_load_all(stream)
-                for doc in documents:
-                    if doc.get('spec'):
-                        doc['spec']['template']['spec']['containers'][1]['resources']['limits']['cpu'] = "0.0"
-                    data.append(doc)
-            except yaml.YAMLError as exc:
-                print(exc)
-
-        # Write YAML file
-        with open(os.path.join(base_path, yaml_path), 'w', encoding='utf8') as outfile:
-            yaml.safe_dump_all(data, outfile, default_flow_style=False, allow_unicode=True)
-
     @logger_time_stamp
     def remove_if_exist_run_yaml(self, extension: str = '.yaml'):
         """
@@ -143,23 +112,13 @@ class BenchmarkOperatorWorkloads:
         benchmark_operator_path = 'benchmark-operator'
         current_dir = os.getcwd()
         os.chdir(os.path.join(runner_path, benchmark_operator_path))
+        # Patch for custom image: export IMG=quay.io/user/benchmark-operator:latest;
         self.__ssh.run('make deploy')
         self.__oc.wait_for_pod_create(pod_name='benchmark-controller-manager')
         self.__oc.wait_for_initialized(label='control-plane=controller-manager', label_uuid=False)
         self.__oc.wait_for_ready(label='control-plane=controller-manager', label_uuid=False)
         os.chdir(current_dir)
 
-    @logger_time_stamp
-    def make_undeploy_benchmark_controller_manager_if_exist(self, runner_path: str = environment_variables.environment_variables_dict['runner_path']):
-        """
-        This method make undeploy benchmark controller manager if exist
-        @return:
-        """
-        # delete benchmark-operator pod if exist
-        if self.__oc._is_pod_exist(pod_name='benchmark-controller-manager', namespace=environment_variables.environment_variables_dict['namespace']):
-            logger.info('make undeploy benchmark operator running pod')
-            self.make_undeploy_benchmark_controller_manager(runner_path=runner_path)
-
     @typechecked()
     @logger_time_stamp
     def make_undeploy_benchmark_controller_manager(self, runner_path: str = environment_variables.environment_variables_dict['runner_path']):
@@ -174,6 +133,17 @@ class BenchmarkOperatorWorkloads:
         self.__oc.wait_for_pod_terminate(pod_name='benchmark-controller-manager')
         os.chdir(current_dir)
 
+    @logger_time_stamp
+    def make_undeploy_benchmark_controller_manager_if_exist(self, runner_path: str = environment_variables.environment_variables_dict['runner_path']):
+        """
+        This method make undeploy benchmark controller manager if exist
+        @return:
+        """
+        # delete benchmark-operator pod if exist
+        if self.__oc._is_pod_exist(pod_name='benchmark-controller-manager', namespace=environment_variables.environment_variables_dict['namespace']):
+            logger.info('make undeploy benchmark operator running pod')
+            self.make_undeploy_benchmark_controller_manager(runner_path=runner_path)
+
     @typechecked()
     @logger_time_stamp
     def helm_install_benchmark_operator(self, runner_path: str = environment_variables.environment_variables_dict['runner_path']):
@@ -232,11 +202,28 @@ class BenchmarkOperatorWorkloads:
     def tear_down_vm_after_error(self, yaml: str, vm_name: str):
         """
         This method tear down vm in case of error
+        @param yaml:
+        @param vm_name:
         """
         self.__oc.delete_vm_sync(yaml=yaml, vm_name=vm_name)
         self.remove_if_exist_run_yaml()
         self.make_undeploy_benchmark_controller_manager(runner_path=environment_variables.environment_variables_dict['runner_path'])
 
+    @logger_time_stamp
+    def system_metrics_collector(self, workload: str):
+        """
+        This method run system metrics collector
+        @param workload:
+        :return:
+        """
+        self.__oc.wait_for_pod_create(pod_name='system-metrics-collector')
+        self.__oc.wait_for_initialized(label='app=system-metrics-collector', workload=workload)
+        self.__oc.wait_for_pod_completed(label='app=system-metrics-collector', workload=workload)
+        # verify that data upload to elastic search
+        if self.__es_host:
+            self.__es_operations.verify_es_data_uploaded(index=f'system-metrics',
+                                                         uuid=self.__oc.get_long_uuid(workload=workload))
+
 #***********************************************************************************************
 ######################################## Workloads #############################################
 #***********************************************************************************************
@@ -252,7 +239,10 @@ class BenchmarkOperatorWorkloads:
             self.__oc.create_pod_sync(yaml=os.path.join(f'{self.__current_run_path}', f'{self.stressng_pod.__name__}.yaml'), pod_name=f'{workload}-workload')
             self.__oc.wait_for_initialized(label='app=stressng_workload', workload=workload)
             self.__oc.wait_for_ready(label='app=stressng_workload', workload=workload)
-            self.__oc.wait_for_completed(label='app=stressng_workload', workload=workload)
+            self.__oc.wait_for_pod_completed(label='app=stressng_workload', workload=workload)
+            # system metrics
+            if environment_variables.environment_variables_dict['system_metrics'] == 'True':
+                self.system_metrics_collector(workload=workload)
             if self.__es_host:
                 # verify that data upload to elastic search according to unique uuid
                 self.__es_operations.verify_es_data_uploaded(index=f'{workload}-results', uuid=self.__oc.get_long_uuid(workload=workload))
@@ -279,7 +269,11 @@ class BenchmarkOperatorWorkloads:
             self.__oc.create_vm_sync(yaml=os.path.join(f'{self.__current_run_path}', f'{self.stressng_vm.__name__}.yaml'), vm_name=f'{workload}-workload')
             self.__oc.wait_for_initialized(label='app=stressng_workload', workload=workload)
             self.__oc.wait_for_ready(label='app=stressng_workload', workload=workload)
-            # verify that data upload to elastic search, vm completed status
+            self.__oc.wait_for_vm_completed(workload=workload)
+            # system metrics
+            if environment_variables.environment_variables_dict['system_metrics'] == 'True':
+               self.system_metrics_collector(workload=workload)
+            # verify that data upload to elastic search
             if self.__es_host:
                 self.__es_operations.verify_es_data_uploaded(index=f'{workload}-results', uuid=self.__oc.get_long_uuid(workload=workload))
             self.__oc.delete_vm_sync(
@@ -314,7 +308,10 @@ class BenchmarkOperatorWorkloads:
             self.__oc.wait_for_pod_create(pod_name=f'uperf-client')
             self.__oc.wait_for_initialized(label='app=uperf-bench-client', workload=workload)
             self.__oc.wait_for_ready(label='app=uperf-bench-client', workload=workload)
-            self.__oc.wait_for_completed(label='app=uperf-bench-client', workload=workload)
+            self.__oc.wait_for_pod_completed(label='app=uperf-bench-client', workload=workload)
+            # system metrics
+            if environment_variables.environment_variables_dict['system_metrics'] == 'True':
+                self.system_metrics_collector(workload=workload)
             if self.__es_host:
                 # verify that data upload to elastic search
                 self.__es_operations.verify_es_data_uploaded(index=f'{workload}-results', uuid=self.__oc.get_long_uuid(workload=workload), workload=self.uperf_pod.__name__)
@@ -345,7 +342,11 @@ class BenchmarkOperatorWorkloads:
             self.__oc.wait_for_vm_create(vm_name='uperf-client')
             self.__oc.wait_for_initialized(label='app=uperf-bench-client', workload=workload)
             self.__oc.wait_for_ready(label='app=uperf-bench-client', workload=workload)
-            # verify that data upload to elastic search, vm completed status
+            self.__oc.wait_for_vm_completed(workload=workload)
+            # system metrics
+            if environment_variables.environment_variables_dict['system_metrics'] == 'True':
+                self.system_metrics_collector(workload=workload)
+            # verify that data upload to elastic search
             if self.__es_host:
                 self.__es_operations.verify_es_data_uploaded(index=f'{workload}-results', uuid=self.__oc.get_long_uuid(workload=workload), workload=self.uperf_vm.__name__)
             self.__oc.delete_vm_sync(yaml=os.path.join(f'{self.__current_run_path}', f'{self.uperf_vm.__name__}.yaml'),
@@ -376,15 +377,18 @@ class BenchmarkOperatorWorkloads:
             self.__oc.wait_for_pod_create(pod_name=f'{workload}-creator')
             self.__oc.wait_for_initialized(label='app=hammerdb_creator', workload=workload)
             self.__oc.wait_for_ready(label='app=hammerdb_creator', workload=workload)
-            self.__oc.wait_for_completed(label='app=hammerdb_creator', workload=workload)
+            self.__oc.wait_for_pod_completed(label='app=hammerdb_creator', workload=workload)
             # hammerdb workload
             self.__oc.wait_for_pod_create(pod_name=f'{workload}-workload')
             self.__oc.wait_for_initialized(label='app=hammerdb_workload', workload=workload)
             self.__oc.wait_for_ready(label='app=hammerdb_workload', workload=workload)
-            self.__oc.wait_for_completed(label='app=hammerdb_workload', workload=workload)
+            self.__oc.wait_for_pod_completed(label='app=hammerdb_workload', workload=workload)
+            # system metrics
+            if environment_variables.environment_variables_dict['system_metrics'] == 'True':
+                self.system_metrics_collector(workload=workload)
             if self.__es_host:
                 # verify that data upload to elastic search
-                self.__es_operations.verify_es_data_uploaded(index=f'{workload}-results', uuid=self.__oc.get_long_uuid(workload=workload))
+                self.__es_operations.verify_es_data_uploaded(index=f'hammerdb-results', uuid=self.__oc.get_long_uuid(workload=workload))
             # delete hammerdb
             self.__oc.delete_pod_sync(
                 yaml=os.path.join(f'{self.__current_run_path}', f'{self.hammerdb_pod.__name__}_{database}.yaml'),
@@ -424,9 +428,13 @@ class BenchmarkOperatorWorkloads:
             self.__oc.wait_for_vm_create(vm_name=f'{workload}-workload')
             self.__oc.wait_for_initialized(label='app=hammerdb_workload', workload=workload)
             self.__oc.wait_for_ready(label='app=hammerdb_workload', workload=workload)
-            # verify that data upload to elastic search, vm completed status
+            self.__oc.wait_for_vm_completed(workload=workload)
+            # system metrics
+            if environment_variables.environment_variables_dict['system_metrics'] == 'True':
+                self.system_metrics_collector(workload=workload)
+            # verify that data upload to elastic search
             if self.__es_host:
-                self.__es_operations.verify_es_data_uploaded(index=f'{workload}-results', uuid=self.__oc.get_long_uuid(workload=workload))
+                self.__es_operations.verify_es_data_uploaded(index=f'hammerdb-results', uuid=self.__oc.get_long_uuid(workload=workload))
             self.__oc.delete_vm_sync(
                 yaml=os.path.join(f'{self.__current_run_path}', f'{self.hammerdb_vm.__name__}_{database}.yaml'),
                 vm_name=f'{workload}-workload')
@@ -472,11 +480,9 @@ class BenchmarkOperatorWorkloads:
         :return:
         """
 
+        # make undeploy benchmark controller manager if exist
         self.make_undeploy_benchmark_controller_manager_if_exist(runner_path=environment_variables.environment_variables_dict['runner_path'])
 
-        #  elasticsearch is must for VM workload for completed status verifications
-        self.__verify_elasticsearch_exist_for_vm_workload(workload)
-
         # make deploy benchmark controller manager
         self.make_deploy_benchmark_controller_manager(runner_path=environment_variables.environment_variables_dict['runner_path'])
 
