@@ -10,15 +10,20 @@ class EnvironmentVariables:
 
         self._environment_variables_dict = {}
 
-        # hard coded parameters
+        # Constant parameters
         self._environment_variables_dict['workloads'] = ['stressng_pod', 'stressng_vm', 'uperf_pod', 'uperf_vm', 'hammerdb_pod_mariadb', 'hammerdb_vm_mariadb',  'hammerdb_pod_postgres', 'hammerdb_vm_postgres', 'hammerdb_pod_mssql', 'hammerdb_vm_mssql']
-        self._environment_variables_dict['namespace'] = os.environ.get('namespace', 'benchmark-operator')
-        # run Hammerdb workload with ocs pvc
-        self._environment_variables_dict['ocs_pvc'] = os.environ.get('ocs_pvc', 'true')
-        #  TODO: CPU issue in functional environment, need to walk around only in Azure functional environment
-        self._environment_variables_dict['functional_resource_limit'] = os.environ.get('functional_resource_limit', 'true')
+        self._environment_variables_dict['namespace'] = os.environ.get('NAMESPACE', 'benchmark-operator')
+        # run Hammerdb workload with ocs pvc True/False
+        self._environment_variables_dict['ocs_pvc'] = os.environ.get('OCS_PVC', 'True')
+        # This parameter get from CI.yml file
+        self._environment_variables_dict['build_version'] = os.environ.get('BUILD_VERSION', '1.0.0')
+        # collect system metrics True/False
+        self._environment_variables_dict['system_metrics'] = os.environ.get('SYSTEM_METRICS', 'True')
 
+        # This path is for benchmark-operator path
+        self._environment_variables_dict['runner_path'] = os.environ.get('RUNNER_PATH', '/')
         ##################################################################################################
+
         # dynamic parameters - configure for local run
         self._environment_variables_dict['workload'] = os.environ.get('WORKLOAD', '')
         self._environment_variables_dict['kubeadmin_password'] = os.environ.get('KUBEADMIN_PASSWORD', '')
@@ -32,8 +37,16 @@ class EnvironmentVariables:
         self._environment_variables_dict['elasticsearch'] = os.environ.get('ELASTICSEARCH', '')
         self._environment_variables_dict['elasticsearch_port'] = os.environ.get('ELASTICSEARCH_PORT', '')
 
-        # This path is for benchmark-operator path
-        self._environment_variables_dict['runner_path'] = os.environ.get('RUNNER_PATH', '')
+        # Azure details
+        self._environment_variables_dict['azure_cluster_stop'] = os.environ.get('AZURE_CLUSTER_STOP', '')
+        self._environment_variables_dict['azure_cluster_start'] = os.environ.get('AZURE_CLUSTER_START', '')
+        self._environment_variables_dict['azure_clientid'] = os.environ.get('AZURE_CLIENTID', '')
+        self._environment_variables_dict['azure_secret'] = os.environ.get('AZURE_SECRET', '')
+        self._environment_variables_dict['azure_tenantid'] = os.environ.get('AZURE_TENANTID', '')
+        self._environment_variables_dict['azure_subscriptionid'] = os.environ.get('AZURE_SUBSCRIPTIONID', '')
+        self._environment_variables_dict['azure_resource_group_name'] = os.environ.get('AZURE_RESOURCE_GROUP_NAME', '')
+        self._environment_variables_dict['azure_vm_name'] = os.environ.get('AZURE_VM_NAME', '')
+
         # end dynamic parameters - configure for local run
         ##################################################################################################
 
@@ -48,7 +61,7 @@ class EnvironmentVariables:
 
         # ElasticSearch functionality
         if self._environment_variables_dict['elasticsearch'] and self._environment_variables_dict['elasticsearch_port']:
-            self._environment_variables_dict['elasticsearch_url'] = f"{self._environment_variables_dict['elasticsearch']}:{self._environment_variables_dict['elasticsearch_port']}"
+            self._environment_variables_dict['elasticsearch_url'] = f"http://{self._environment_variables_dict['elasticsearch']}:{self._environment_variables_dict['elasticsearch_port']}"
         else:
             self._environment_variables_dict['elasticsearch_url'] = ''
 
